@@ -1,4 +1,4 @@
-/*  ident_auth.c,v 1.13 2004/06/17 01:27:52 eagle Exp
+/*  $Id: ident_auth.c 590 2005-09-23 01:48:18Z eagle $
 **
 **  SASL-based authentication mechanisms for identd.
 **
@@ -315,14 +315,14 @@ krb_is_ticket(char *tf_name, struct ident_auth_data *auth_data)
 
     /* Can we even stat the file? */
     if (lstat(tf_name, &stat_buf) < 0) {
-        if (debug_flag && syslog_flag)
+        if (verbose_flag)
             syslog(LOG_DEBUG, "lstat error %d on %s", errno, tf_name);
         return (errno == ENOENT) ? NO_TKT_FIL : TKT_FIL_ACC;
     }
 
     /* Check ownership */
     if (stat_buf.st_uid != auth_data->uid ) {
-        if (debug_flag && syslog_flag)
+        if (verbose_flag)
             syslog(LOG_DEBUG, "UID mismatch %d : %d on %s", stat_buf.st_uid,
                    auth_data->uid, tf_name);
         return TKT_FIL_ACC;
@@ -330,7 +330,7 @@ krb_is_ticket(char *tf_name, struct ident_auth_data *auth_data)
 
     /* Check file perms for 600. */
     if ((stat_buf.st_mode & S_IRUSR) != S_IRUSR) {
-        if (debug_flag && syslog_flag)
+        if (verbose_flag)
             syslog(LOG_DEBUG, "User can't read %s", tf_name);
         return TKT_FIL_ACC;
     }
@@ -338,8 +338,8 @@ krb_is_ticket(char *tf_name, struct ident_auth_data *auth_data)
         || ((stat_buf.st_mode & S_IWGRP) == S_IWGRP)
         || ((stat_buf.st_mode & S_IROTH) == S_IROTH)
         || ((stat_buf.st_mode & S_IWOTH) == S_IWOTH)) {
-        if (syslog_flag)
-            syslog(LOG_ALERT, "Incorrect file permissons on %s : %o",
+        if (verbose_flag)
+            syslog(LOG_DEBUG, "Incorrect file permissions on %s : %o",
                    tf_name, stat_buf.st_mode);
         return TKT_FIL_ACC ;
     }
@@ -351,7 +351,7 @@ krb_is_ticket(char *tf_name, struct ident_auth_data *auth_data)
     code =  tf_init(tf_name, R_TKT_FIL);
     if (code != KSUCCESS) {
         tf_close();
-        if (debug_flag && syslog_flag)
+        if (verbose_flag)
             syslog(LOG_DEBUG, "tf_init failed %s", tf_name);
         return code;
     }
@@ -375,7 +375,7 @@ krb_is_ticket(char *tf_name, struct ident_auth_data *auth_data)
     }
     tf_close();
     if (syslog_flag)
-        syslog(LOG_INFO, "Ticket file %s : %s.%s for %d", tf_name, pname,
+        syslog(LOG_INFO, "ticket file %s: %s.%s for %d", tf_name, pname,
                pinst, auth_data->uid);
 
     return KSUCCESS;
@@ -415,7 +415,7 @@ krb_find_ticket(char *tktstring, struct ident_auth_data *auth_data)
             closedir(temp_dir);
             return IDENT_AUTH_OKAY;
         }
-        if (syslog_flag && debug_flag)
+        if (verbose_flag)
             syslog(LOG_DEBUG, "Rejected %s : %d", dp->d_name, rcode);
     }
     closedir(temp_dir);
@@ -469,7 +469,7 @@ krb_responder_start(struct ident_auth_data *auth_data)
             *p = tolower((int) *p);
     strncpy(realm, krb_realmofhost(host), REALM_SZ - 1);
     free(host);
-    if (syslog_flag && debug_flag)
+    if (verbose_flag)
         syslog(LOG_DEBUG, "Fetching ticket :%s.%s@%s:",
                IDENT_AUTH_KRB_SERVICE, instance, realm);
 
@@ -584,7 +584,7 @@ krb_responder_auth(struct ident_auth_data *auth_data)
             resp_len = 4 * (munch) + i + k - j;
 
             /* Log what we're doing for debugging purposes. */
-            if (syslog_flag && debug_flag) {
+            if (verbose_flag) {
                 syslog(LOG_DEBUG, "Data: %4.4x:%4.4x:%4.4x:%4.4x:%s",
                        htons(mutual_auth_flag),
                        htons(auth_data->remote_port),
@@ -640,7 +640,7 @@ krb_responder_auth(struct ident_auth_data *auth_data)
                 || (auth_reply.remote_port != auth_data->remote_port)
                 || (strncmp(auth_reply.auth_struct->auth_method,
                             "KERBEROS_V4", strlen("KERBEROS_V4")) != 0)) {
-                if (debug_flag && syslog_flag)
+                if (verbose_flag)
                     syslog(LOG_DEBUG, "Auth reply does not match auth_data"
                            " %d,%d : %d,%d", auth_reply.local_port,
                            auth_reply.remote_port, auth_data->local_port,
@@ -664,12 +664,12 @@ krb_responder_auth(struct ident_auth_data *auth_data)
             challenge = ntohl(challenge);
             if (challenge != kstate->challenge + 1) {
                 kstate->authstepno = -1;
-                if (debug_flag && syslog_flag)
+                if (verbose_flag)
                     syslog(LOG_DEBUG, "Challenge failed: %d:%d",
                            kstate->challenge, challenge);
                 return IDENT_MUTUAL_AUTH_FAIL;
             }
-            if (debug_flag && syslog_flag)
+            if (verbose_flag)
                 syslog(LOG_DEBUG, "Challenge succeeded: %d:%d",
                        kstate->challenge, challenge);
             return IDENT_AUTH_OKAY;
